@@ -5,8 +5,10 @@
 #include <QDir>
 #include <QTimer>
 
-#ifdef Q_WS_MAEMO_5
+#if defined(Q_WS_MAEMO_5)
 #   include <QAbstractKineticScroller>
+#elif defined(Q_OS_SYMBIAN)
+#   include "flickcharm.h"
 #endif
 
 #include "book.h"
@@ -39,12 +41,12 @@ BookView::BookView(QWidget *parent):
     settings()->setDefaultTextEncoding("utf-8");
     page()->setContentEditable(false);
 
-#if defined(Q_WS_MAEMO_5)
-    // Suppress unwanted text selections on Maemo
+#if defined(Q_WS_MAEMO_5) || defined(Q_OS_SYMBIAN)
+    // Suppress unwanted text selections on Maemo and Symbian
     installEventFilter(this);
 #endif
     QWebFrame *frame = page()->mainFrame();
-#if defined(Q_WS_MAEMO_5)
+#if defined(Q_WS_MAEMO_5) || defined(Q_OS_SYMBIAN)
     frame->setScrollBarPolicy(Qt::Vertical, Qt::ScrollBarAlwaysOff);
 #endif
     frame->setScrollBarPolicy(Qt::Horizontal, Qt::ScrollBarAlwaysOff);
@@ -72,9 +74,12 @@ BookView::BookView(QWidget *parent):
     s->setValue("scheme", s->value("scheme", "default"));
     setBook(0);
 
-#ifdef Q_WS_MAEMO_5
+#if defined(Q_WS_MAEMO_5)
     scrollerMonitor = 0;
     scroller = property("kineticScroller").value<QAbstractKineticScroller *>();
+#elif defined(Q_OS_SYMBIAN)
+    FlickCharm *charm = new FlickCharm(this);
+    charm->activateOn(this);
 #endif
 }
 
@@ -282,7 +287,7 @@ void BookView::wheelEvent(QWheelEvent *e)
     showProgress();
 }
 
-void BookView::addBookmark()
+void BookView::addBookmark(const QString &note)
 {
     Trace t("BookView::addBookmark");
     if (!mBook) {
@@ -291,7 +296,7 @@ void BookView::addBookmark()
     int y = page()->mainFrame()->scrollPosition().y();
     int height = page()->mainFrame()->contentsSize().height();
     qDebug() << ((qreal)y / (qreal)height);
-    mBook->addBookmark(contentIndex, (qreal)y / (qreal)height);
+    mBook->addBookmark(contentIndex, (qreal)y / (qreal)height, note);
     update();
 }
 
@@ -400,9 +405,8 @@ void BookView::timerEvent(QTimerEvent *e)
             killTimer(scrollerMonitor);
         }
     }
-#else
-    Q_UNUSED(e);
-#endif // Q_WS_MAEMO_5
+#endif
+    QWebView::timerEvent(e);
 }
 
 void BookView::keyPressEvent(QKeyEvent* event)
