@@ -6,6 +6,7 @@
 #include <QStringList>
 #include <QHash>
 #include <QImage>
+#include <QPoint>
 
 #include "book.h"
 
@@ -24,7 +25,7 @@ public:
     void setBook(Book *book);
     Book *book();
     void goToBookmark(const Book::Bookmark &bookmark);
-    void addBookmark();
+    void addBookmark(const QString &note);
     void setLastBookmark();
     void restoreLastBookmark();
 
@@ -95,7 +96,7 @@ private:
     bool mousePressed;
     int contentsHeight; /**< Last know height of the frame. */
 
-#ifdef Q_WS_MAEMO_5
+#if defined(Q_WS_MAEMO_5)
     int scrollerMonitor;
     QAbstractKineticScroller *scroller;
 #endif
