@@ -6,12 +6,13 @@
 class QWidget;
 class Book;
 
+/** Display book information. */
 class InfoDialog: public Dyalog
 {
     Q_OBJECT
 
 public:
-    explicit InfoDialog(Book *book, QWidget *parent = 0);
+    explicit InfoDialog(Book *book, QWidget *parent, bool showButtons = true);
 
 public slots:
     void onReadBook();
