@@ -34,15 +34,14 @@
 #include "progress.h"
 #include "dyalog.h"
 #include "translucentbutton.h"
+#include "platform.h"
+#include "progressdialog.h"
 
 #ifdef DORIAN_TEST_MODEL
 #   include "modeltest.h"
 #endif
 
-const int PROGRESS_HEIGHT = 17;
-static const char *DORIAN_VERSION =
-#include "pkg/version.txt"
-;
+const int DORIAN_PROGRESS_HEIGHT = 17;
 
 MainWindow::MainWindow(QWidget *parent):
     AdopterWindow(parent), view(0), preventBlankingTimer(-1)
@@ -74,6 +73,11 @@ MainWindow::MainWindow(QWidget *parent):
 
     // Tool bar actions
 
+#ifdef Q_OS_SYMBIAN
+    fullScreenAction = addToolBarAction(this, SLOT(showBig()),
+                                        "view-fullscreen", tr("Full screen"));
+#endif
+
     chaptersAction = addToolBarAction(this, SLOT(showChapters()),
                                       "chapters", tr("Chapters"));
     bookmarksAction = addToolBarAction(this, SLOT(showBookmarks()),
@@ -98,9 +102,11 @@ MainWindow::MainWindow(QWidget *parent):
     addToolBarAction(this, SLOT(about()), "about", tr("About"));
 #endif // Q_WS_MAEMO_5
 
+#ifndef Q_OS_SYMBIAN
     addToolBarSpace();
     fullScreenAction = addToolBarAction(this, SLOT(showBig()),
                                         "view-fullscreen", tr("Full screen"));
+#endif
 
     // Buttons on top of the book view
     previousButton = new TranslucentButton("back", this);
@@ -111,11 +117,7 @@ MainWindow::MainWindow(QWidget *parent):
             this, SLOT(onCurrentBookChanged()));
 
     // Load library, upgrade it if needed
-    libraryProgress = new QProgressDialog(tr("Upgrading library"), "", 0, 0, this);
-    libraryProgress->reset();
-    libraryProgress->setMinimumDuration(0);
-    libraryProgress->setWindowModality(Qt::WindowModal);
-    libraryProgress->setCancelButton(0);
+    libraryProgress = new ProgressDialog(tr("Upgrading library"), this);
     Library *library = Library::instance();
     connect(library, SIGNAL(beginUpgrade(int)), this, SLOT(onBeginUpgrade(int)));
     connect(library, SIGNAL(upgrading(const QString &)),
@@ -195,7 +197,7 @@ void MainWindow::showRegular()
     otherChildren << progress << previousButton << nextButton;
     takeChildren(view, otherChildren);
     QRect geo = geometry();
-    progress->setGeometry(0, 0, geo.width(), PROGRESS_HEIGHT);
+    progress->setGeometry(0, 0, geo.width(), DORIAN_PROGRESS_HEIGHT);
 #if defined(Q_WS_MAEMO_5)
     previousButton->setGeometry(0,
         geo.height() - toolBar->height() - TranslucentButton::pixels,
@@ -228,7 +230,7 @@ void MainWindow::showBig()
     QList<QWidget *> otherChildren;
     otherChildren << progress << nextButton << previousButton;
     QRect screen = QApplication::desktop()->screenGeometry();
-    progress->setGeometry(0, 0, screen.width(), PROGRESS_HEIGHT);
+    progress->setGeometry(0, 0, screen.width(), DORIAN_PROGRESS_HEIGHT);
 #if defined(Q_WS_MAEMO_5)
     nextButton->setGeometry(screen.width() - TranslucentButton::pixels, 0,
         TranslucentButton::pixels, TranslucentButton::pixels);
@@ -283,7 +285,8 @@ void MainWindow::showBookmarks()
     if (book) {
         BookmarksDialog *bookmarks = new BookmarksDialog(book, this);
         bookmarks->setWindowModality(Qt::WindowModal);
-        connect(bookmarks, SIGNAL(addBookmark()), this, SLOT(onAddBookmark()));
+        connect(bookmarks, SIGNAL(addBookmark(const QString &)),
+                this, SLOT(onAddBookmark(const QString &)));
         connect(bookmarks, SIGNAL(goToBookmark(int)),
                 this, SLOT(onGoToBookmark(int)));
         bookmarks->show();
@@ -355,10 +358,10 @@ void MainWindow::onPartLoadEnd(int index)
 #endif // Q_WS_MAEMO_5
 }
 
-void MainWindow::onAddBookmark()
+void MainWindow::onAddBookmark(const QString &note)
 {
     Trace t("MainWindow:onAddBookmark");
-    view->addBookmark();
+    view->addBookmark(note);
 }
 
 void MainWindow::onGoToBookmark(int index)
@@ -403,12 +406,13 @@ void MainWindow::timerEvent(QTimerEvent *event)
 #endif // Q_WS_MAEMO_5
         qDebug() << "MainWindow::timerEvent: Prevent display blanking";
     }
+    AdopterWindow::timerEvent(event);
 }
 
 void MainWindow::resizeEvent(QResizeEvent *e)
 {
     Trace t("MainWindow::resizeEvent");
-    progress->setGeometry(QRect(0, 0, e->size().width(), PROGRESS_HEIGHT));
+    progress->setGeometry(QRect(0, 0, e->size().width(), DORIAN_PROGRESS_HEIGHT));
 #if defined(Q_WS_MAEMO_5)
     previousButton->setGeometry(0,
         e->size().height() - toolBar->height() - TranslucentButton::pixels,
@@ -434,7 +438,7 @@ void MainWindow::resizeEvent(QResizeEvent *e)
 
 void MainWindow::about()
 {
-    Dyalog *aboutDialog = new Dyalog(this);
+    Dyalog *aboutDialog = new Dyalog(this, false);
     aboutDialog->setWindowTitle(tr("About Dorian"));
     QLabel *label = new QLabel(aboutDialog);
     label->setTextFormat(Qt::RichText);
@@ -444,7 +448,7 @@ void MainWindow::about()
         "Akos Polster &lt;akos@pipacs.com&gt;<br>"
         "Licensed under GNU General Public License, Version 3<br>"
         "Source code: <a href='https://garage.maemo.org/projects/dorian/'>"
-        "garage.maemo.org/projects/dorian</a>").arg(DORIAN_VERSION));
+        "garage.maemo.org/projects/dorian</a>").arg(Platform::version()));
     aboutDialog->addWidget(label);
     aboutDialog->addStretch();
     aboutDialog->show();
