@@ -12,6 +12,7 @@ class BookView;
 class Book;
 class FullScreenWindow;
 class Progress;
+class ProgressDialog;
 class TranslucentButton;
 
 class MainWindow: public AdopterWindow
@@ -34,7 +35,7 @@ public slots:
     void onSettingsChanged(const QString &key);
     void onPartLoadStart();
     void onPartLoadEnd(int index);
-    void onAddBookmark();
+    void onAddBookmark(const QString &note);
     void onGoToBookmark(int index);
     void showChapters();
     void onGoToChapter(int index);
@@ -73,7 +74,7 @@ private:
     Progress *progress;
     TranslucentButton *previousButton;
     TranslucentButton *nextButton;
-    QProgressDialog *libraryProgress;
+    ProgressDialog *libraryProgress;
 };
 
 #endif // MAINWINDOW_H
