@@ -27,11 +27,13 @@ public:
     /** Bookmark: a volume index and a relative position in volume. */
     struct Bookmark
     {
-        Bookmark(int part_, qreal pos_): part(part_), pos(pos_) {}
+        Bookmark(int part_, qreal pos_, const QString &note_ = QString()):
+                part(part_), pos(pos_), note(note_) {}
         Bookmark(): part(0), pos(0.0) {}
         int part;
         qreal pos;
-        bool operator<(const Bookmark&other) const {
+        QString note;
+        bool operator<(const Bookmark &other) const {
             return (part == other.part)? (pos < other.pos): (part < other.part);
         }
     };
@@ -85,7 +87,7 @@ public:
     Bookmark lastBookmark() const;
 
     /** Add bookmark. */
-    void addBookmark(int part, qreal position);
+    void addBookmark(int part, qreal position, const QString &note);
 
     /** Delete bookmark. */
     void deleteBookmark(int index);
