@@ -8,6 +8,7 @@ class QWidget;
 class QPushButton;
 class QScrollArea;
 class QVBoxLayout;
+class QMenu;
 
 /** Maemo- and Mac-friendly dialog box. */
 class Dyalog: public QDialog
@@ -24,17 +25,24 @@ public:
     void addStretch(int stretch = 0);
 
     /** Add button to the dialog button box. */
-    void addButton(QPushButton *button,
+    void addButton(const QString &label, QObject *receiver, const char *slot,
         QDialogButtonBox::ButtonRole role = QDialogButtonBox::AcceptRole);
 
-    /** Add standard button to the dialog button box. */
-    QPushButton *addButton(QDialogButtonBox::StandardButton button);
+public slots:
+#ifdef Q_OS_SYMBIAN
+    void show();
+    int exec();
+#endif
 
 protected:
     QScrollArea *scroller;
     QWidget *content;
     QVBoxLayout *contentLayout;
     QDialogButtonBox *buttonBox;
+    bool showButtons;
+#ifdef Q_OS_SYMBIAN
+    QMenu *menu;
+#endif
 };
 
 #endif // DYALOG_H
