@@ -3,10 +3,15 @@
 #include "listwindow.h"
 #include "trace.h"
 #include "listview.h"
+#include "platform.h"
+
+#ifdef Q_OS_SYMBIAN
+#include "flickcharm.h"
+#endif
 
 ListWindow::ListWindow(QWidget *parent): QMainWindow(parent), list(0)
 {
-#ifdef Q_WS_MAEMO_5
+#if defined(Q_WS_MAEMO_5)
     setAttribute(Qt::WA_Maemo5StackedWindow, true);
     popup = new QMenu(this);
 
@@ -31,16 +36,17 @@ ListWindow::ListWindow(QWidget *parent): QMainWindow(parent), list(0)
     setCentralWidget(frame);
     contentLayout = new QHBoxLayout();
     frame->setLayout(contentLayout);
-#   ifdef Q_OS_SYMBIAN
+    buttonBox = new QDialogButtonBox(Qt::Vertical, this);
+    contentLayout->addWidget(buttonBox);
+#endif // Q_WS_MAEMO_5
+
+#ifdef Q_OS_SYMBIAN
+    charm = 0;
     QAction *closeAction = new QAction(parent? tr("Back"): tr("Exit"), this);
     closeAction->setSoftKeyRole(QAction::NegativeSoftKey);
     connect(closeAction, SIGNAL(triggered()), this, SLOT(close()));
     QMainWindow::addAction(closeAction);
-#   else
-    buttonBox = new QDialogButtonBox(Qt::Vertical, this);
-    contentLayout->addWidget(buttonBox);
-#   endif // Q_OS_SYMBIAN
-#endif // Q_WS_MAEMO_5
+#endif // Q_OS_SYMBIAN
 
 #ifdef Q_WS_MAC
     addAction(tr("Close"), this, SLOT(close()), QString(),
@@ -52,7 +58,7 @@ void ListWindow::addList(ListView *listView)
 {
     Trace t("ListWindow::addList");
     list = listView;
-#ifdef Q_WS_MAEMO_5
+#if defined(Q_WS_MAEMO_5)
     list->installEventFilter(this);
     list->setMinimumHeight(list->contentsHeight());
     contentLayout->addWidget(list);
@@ -64,7 +70,15 @@ void ListWindow::addList(ListView *listView)
             this, SLOT(onModelChanged()));
 #else
     contentLayout->insertWidget(0, list);
-#endif
+#endif // Q_WS_MAEMO5
+
+#ifdef Q_OS_SYMBIAN
+    if (!charm) {
+        charm = new FlickCharm(this);
+    }
+    // FIXME: Charm's need more work...: charm->activateOn(list);
+#endif // Q_OS_SYMBIAN
+
     connect(list->selectionModel(),
       SIGNAL(selectionChanged(const QItemSelection &, const QItemSelection &)),
       this,
@@ -72,23 +86,25 @@ void ListWindow::addList(ListView *listView)
 }
 
 void ListWindow::addAction(const QString &title, QObject *receiver,
-                           const char *slot, const QString &iconPath,
+                           const char *slot, const QString &iconName,
                            QDialogButtonBox::ButtonRole role)
 {
     Trace t("ListWindow::addAction");
 #ifdef Q_WS_MAEMO_5
     Q_UNUSED(role);
-    QPushButton *button = new QPushButton(QIcon(iconPath), title, this);
+    QPushButton *button =
+            new QPushButton(QIcon(Platform::icon(iconName)), title, this);
     contentLayout->addWidget(button);
     connect(button, SIGNAL(clicked()), receiver, slot);
 #elif defined(Q_OS_SYMBIAN)
     Q_UNUSED(role);
+    Q_UNUSED(iconName);
     QAction *action = new QAction(title, this);
     connect(action, SIGNAL(triggered()), receiver, slot);
     action->setSoftKeyRole(QAction::PositiveSoftKey);
     menuBar()->addAction(action);
 #else
-    Q_UNUSED(iconPath);
+    Q_UNUSED(iconName);
     QPushButton *button = buttonBox->addButton(title, role);
     connect(button, SIGNAL(clicked()), receiver, slot);
 #endif // Q_WS_MAEMO_5
